@@ -31,8 +31,8 @@
 #include <QAction>
 #include <QCommandLineParser>
 #include <QIcon>
-#include <QRegExp>
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QRegExp>
 #include <QRegExpValidator>
 #endif
 #include <QDialog>
@@ -215,11 +215,7 @@ bool KWalletManager::queryClose()
         if (!_tray) {
             qApp->quit();
         } else {
-#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 91, 0)
             _tray->hideAssociatedWidget();
-#else
-            hide();
-#endif
         }
         return false;
     }
@@ -614,17 +610,11 @@ void KWalletManager::activateForStartLikeCall(bool showWindow)
     if (showWindow) {
         show();
     }
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 91, 0)
     KWindowSystem::updateStartupId(windowHandle());
-#else
-    if (KWindowSystem::isPlatformWayland()) {
-        KWindowSystem::setCurrentXdgActivationToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"));
-        //
-    }
-#endif
+
     if (showWindow) {
         if (isMinimized())
-            KWindowSystem::unminimizeWindow(winId());
+            setWindowState(windowState() & ~Qt::WindowMinimized);
         else if (_tray && !isVisible()) // TODO: how does this relate to show() above?
             _tray->activate(QPoint());
     }
@@ -632,7 +622,7 @@ void KWalletManager::activateForStartLikeCall(bool showWindow)
     if (isVisible()) {
         if (!isActiveWindow()) {
             raise();
-            KWindowSystem::activateWindow(winId());
+            KWindowSystem::activateWindow(windowHandle());
         }
     }
 }
